==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/RegistrationInlineHookPPDataAllOfDataContext.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.InlineHookRequestObject;
import com.okta.sdk.resource.model.RegistrationInlineHookPPDataAllOfDataContextUser;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * RegistrationInlineHookPPDataAllOfDataContext
 */
@JsonPropertyOrder({ RegistrationInlineHookPPDataAllOfDataContext.JSON_PROPERTY_REQUEST,
        RegistrationInlineHookPPDataAllOfDataContext.JSON_PROPERTY_USER })
@JsonTypeName("RegistrationInlineHookPPData_allOf_data_context")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class RegistrationInlineHookPPDataAllOfDataContext implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_REQUEST = "request";
    private InlineHookRequestObject request;

    public static final String JSON_PROPERTY_USER = "user";
    private RegistrationInlineHookPPDataAllOfDataContextUser user;

    public RegistrationInlineHookPPDataAllOfDataContext() {
    }

    public RegistrationInlineHookPPDataAllOfDataContext request(InlineHookRequestObject request) {

        this.request = request;
        return this;
    }

    /**
     * Get request
     *
     * @return request
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_REQUEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public InlineHookRequestObject getRequest() {
        return request;
    }

    @JsonProperty(JSON_PROPERTY_REQUEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRequest(InlineHookRequestObject request) {
        this.request = request;
    }

    public RegistrationInlineHookPPDataAllOfDataContext user(RegistrationInlineHookPPDataAllOfDataContextUser user) {

        this.user = user;
        return this;
    }

    /**
     * Get user
     *
     * @return user
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public RegistrationInlineHookPPDataAllOfDataContextUser getUser() {
        return user;
    }

    @JsonProperty(JSON_PROPERTY_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUser(RegistrationInlineHookPPDataAllOfDataContextUser user) {
        this.user = user;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        RegistrationInlineHookPPDataAllOfDataContext registrationInlineHookPPDataAllOfDataContext = (RegistrationInlineHookPPDataAllOfDataContext) o;
        return Objects.equals(this.request, registrationInlineHookPPDataAllOfDataContext.request)
                && Objects.equals(this.user, registrationInlineHookPPDataAllOfDataContext.user);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(request, user);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class RegistrationInlineHookPPDataAllOfDataContext {\n");
        sb.append("    request: ").append(toIndentedString(request)).append("\n");
        sb.append("    user: ").append(toIndentedString(user)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/RegistrationInlineHookPPDataAllOfDataContext.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.InlineHookRequestObject;
import com.okta.sdk.resource.model.RegistrationInlineHookPPDataAllOfDataContextUser;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * RegistrationInlineHookPPDataAllOfDataContext
 */
@JsonPropertyOrder({ RegistrationInlineHookPPDataAllOfDataContext.JSON_PROPERTY_REQUEST,
        RegistrationInlineHookPPDataAllOfDataContext.JSON_PROPERTY_USER })
@JsonTypeName("RegistrationInlineHookPPData_allOf_data_context")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class RegistrationInlineHookPPDataAllOfDataContext implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_REQUEST = "request";
    private InlineHookRequestObject request;

    public static final String JSON_PROPERTY_USER = "user";
    private RegistrationInlineHookPPDataAllOfDataContextUser user;

    public RegistrationInlineHookPPDataAllOfDataContext() {
    }

    public RegistrationInlineHookPPDataAllOfDataContext request(InlineHookRequestObject request) {

        this.request = request;
        return this;
    }

    /**
     * Get request
     *
     * @return request
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_REQUEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public InlineHookRequestObject getRequest() {
        return request;
    }

    @JsonProperty(JSON_PROPERTY_REQUEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRequest(InlineHookRequestObject request) {
        this.request = request;
    }

    public RegistrationInlineHookPPDataAllOfDataContext user(RegistrationInlineHookPPDataAllOfDataContextUser user) {

        this.user = user;
        return this;
    }

    /**
     * Get user
     *
     * @return user
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public RegistrationInlineHookPPDataAllOfDataContextUser getUser() {
        return user;
    }

    @JsonProperty(JSON_PROPERTY_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUser(RegistrationInlineHookPPDataAllOfDataContextUser user) {
        this.user = user;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        RegistrationInlineHookPPDataAllOfDataContext registrationInlineHookPPDataAllOfDataContext = (RegistrationInlineHookPPDataAllOfDataContext) o;
        return Objects.equals(this.request, registrationInlineHookPPDataAllOfDataContext.request)
                && Objects.equals(this.user, registrationInlineHookPPDataAllOfDataContext.user);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(request, user);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class RegistrationInlineHookPPDataAllOfDataContext {\n");
        sb.append("    request: ").append(toIndentedString(request)).append("\n");
        sb.append("    user: ").append(toIndentedString(user)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
